# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2016-06-27 22:50
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('budget', '0016_auto_20160627_1312'),
    ]

    operations = [
        migrations.AlterField(
            model_name='package',
            name='pub_date',
            field=models.DateTimeField(blank=True, editable=False, null=True),
        ),
        migrations.AlterField(
            model_name='package',
            name='pub_date_resolution',
            field=models.CharField(blank=True, choices=[(b'm', b'Month'), (b'w', b'Week'), (b'd', b'Day'), (b't', b'Time')], default=b'd', editable=False, max_length=1, null=True),
        ),
    ]
