# -*- coding: utf-8 -*-
# Generated by Django 1.10b1 on 2016-06-30 22:36
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('budget', '0020_remove_package_serialized_object'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='package',
            name='print_section',
        ),
        migrations.AddField(
            model_name='package',
            name='print_section',
            field=models.ManyToManyField(blank=True, to='budget.PrintSection'),
        ),
    ]
