# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2016-04-24 18:43
from __future__ import unicode_literals

import django.contrib.postgres.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('budget', '0003_auto_20160420_1800'),
    ]

    operations = [
        migrations.RenameField(
            model_name='package',
            old_name='print_issue',
            new_name='print_run_date',
        ),
        migrations.RemoveField(
            model_name='package',
            name='print_pages',
        ),
        migrations.AddField(
            model_name='package',
            name='is_print_placement_finalized',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='package',
            name='print_placements',
            field=django.contrib.postgres.fields.ArrayField(base_field=models.CharField(blank=True, max_length=15, null=True), blank=True, null=True, size=None),
        ),
    ]
