<div class="icon-holder column small-1 medium-1 large-1">
    <i class="fa fa-search"></i>
</div>
<div class="search-box-holder column small-11 medium-11 large-11">
    <div class="">
        <input id="package-search-box" name="package-search-box" type="text" placeholder="Search people, hubs, verticals and story descriptions..." />
    </div>
</div>