<div class="icon-holder column small-1 medium-1 large-1">
    <i class="fa fa-calendar"></i>
</div>
<div class="date-chooser-holder column small-5 medium-5 large-5">
    <div class=""></div>
    <div id="date-chooser">
        <div id="ugly-date-picker" data-uglydate-large-screen-width="585">
            <div id="search-dates-start-holder">
                <input type="date" name="start-date" placeholder="Select A Date" />
            </div>

            <div id="search-dates-end-holder">
                <input type="date" name="end-date" placeholder="Select A Date" />
            </div>
        </div>

        <input id="budget-dates-start" placeholder="Start date" size="20" value="">
        <span class="start-date-holder"></span>
        <span class="to-label"> to </span>
        <input id="budget-dates-end" placeholder="End date" size="20" value="">
        <span class="end-date-holder"></span>
        <div class="clearer"></div>
    </div>
    <div class=""></div>
</div>
<div class="spacer-column column small-3 medium-3 large-3">&nbsp;</div>
<div class="create-button column small-3 medium-3 large-3">
    <div class="material-button"><a href="{{ homeViewLink }}edit/" tabindex="-1"><span>Create new</span></a></div>
</div>
