<div class="icon-holder column small-1 medium-1 large-1">
    <i class="fa fa-newspaper-o"></i>
</div>

<div class="toggle-holder column small-11 medium-11 large-11">
    <div class="">
        <input id="publication-search-box" name="publication-search-box" type="text" placeholder="Choose a publication..." />
    </div>
</div>
