# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-08-21 02:32
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('budget', '0029_alter_slugs'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='package',
            unique_together=set([('hub', 'slug_key', 'publish_date')]),
        ),
    ]
