<div id="filter-holder" class="center-content row"></div>

<div id="faceted-packages" class="center-content"></div>

<div id="package-list" class="center-content">
      <div class="packages"></div>
</div>
